@@ -660,13 +660,13 @@ double ExecTime(void);
 int Denominator(ContValue Val);
 int GetInt(String S, int N);
 int DateToDay(String DS);
-void DayToDate(int DI, String Date);
+void DayToDate(int DI, String Date, size_t DS_size);
 int TimeToSecs(String TS);
-void SecsToTime(int Secs, String Time);
+void SecsToTime(int Secs, String Time, size_t DS_size);
 void SetTSBase(int y);
 int TStampToMins(String TS);
 void Check(float Val, float Low, float High);
-void CValToStr(ContValue CV, Attribute Att, String DS);
+void CValToStr(ContValue CV, Attribute Att, String DS, size_t DS_size);
 double rint(double v);
 void FreeGlobals(void);
 void Cleanup(void);
