@@ -157,6 +157,7 @@ Boolean ReadName(FILE *f, String s, int n, char ColonOpt)
 void GetNames(FILE *Nf)
 /*   --------  */
 {
+  size_t size = 1000;
   char Buffer[1000] = "", *EndBuff;
   int AttCeiling = 100, ClassCeiling = 100;
   Attribute Att;
@@ -329,16 +330,16 @@ void GetNames(FILE *Nf)
       MaxClass++;
       Realloc(ClassName, MaxClass + 1, String);
 
-      sprintf(Buffer, "%s <= %g", AttName[ClassAtt], ClassThresh[1]);
+      snprintf(Buffer, size, "%s <= %g", AttName[ClassAtt], ClassThresh[1]);
       ClassName[1] = strdup(Buffer);
 
       ForEach(c, 2, MaxClass - 1) {
-        sprintf(Buffer, "%g < %s <= %g", ClassThresh[c - 1], AttName[ClassAtt],
+        snprintf(Buffer, size, "%g < %s <= %g", ClassThresh[c - 1], AttName[ClassAtt],
                 ClassThresh[c]);
         ClassName[c] = strdup(Buffer);
       }
 
-      sprintf(Buffer, "%s > %g", AttName[ClassAtt], ClassThresh[MaxClass - 1]);
+      snprintf(Buffer, size, "%s > %g", AttName[ClassAtt], ClassThresh[MaxClass - 1]);
       ClassName[MaxClass] = strdup(Buffer);
     }
   }
